Documentation
¶
Index ¶
- Variables
- func RegisterServingServiceServer(s *grpc.Server, srv ServingServiceServer)
- type DataFormat
- type DatasetSource
- func (*DatasetSource) Descriptor() ([]byte, []int)
- func (m *DatasetSource) GetDatasetSource() isDatasetSource_DatasetSource
- func (m *DatasetSource) GetFileSource() *DatasetSource_FileSource
- func (*DatasetSource) ProtoMessage()
- func (m *DatasetSource) Reset()
- func (m *DatasetSource) String() string
- func (m *DatasetSource) XXX_DiscardUnknown()
- func (m *DatasetSource) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *DatasetSource) XXX_Merge(src proto.Message)
- func (*DatasetSource) XXX_OneofWrappers() []interface{}
- func (m *DatasetSource) XXX_Size() int
- func (m *DatasetSource) XXX_Unmarshal(b []byte) error
- type DatasetSource_FileSource
- func (*DatasetSource_FileSource) Descriptor() ([]byte, []int)
- func (m *DatasetSource_FileSource) GetDataFormat() DataFormat
- func (m *DatasetSource_FileSource) GetFileUris() []string
- func (*DatasetSource_FileSource) ProtoMessage()
- func (m *DatasetSource_FileSource) Reset()
- func (m *DatasetSource_FileSource) String() string
- func (m *DatasetSource_FileSource) XXX_DiscardUnknown()
- func (m *DatasetSource_FileSource) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *DatasetSource_FileSource) XXX_Merge(src proto.Message)
- func (m *DatasetSource_FileSource) XXX_Size() int
- func (m *DatasetSource_FileSource) XXX_Unmarshal(b []byte) error
- type DatasetSource_FileSource_
- type FeastServingType
- type FeatureReference
- func (*FeatureReference) Descriptor() ([]byte, []int)
- func (m *FeatureReference) GetMaxAge() *duration.Duration
- func (m *FeatureReference) GetName() string
- func (m *FeatureReference) GetProject() string
- func (m *FeatureReference) GetVersion() int32
- func (*FeatureReference) ProtoMessage()
- func (m *FeatureReference) Reset()
- func (m *FeatureReference) String() string
- func (m *FeatureReference) XXX_DiscardUnknown()
- func (m *FeatureReference) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *FeatureReference) XXX_Merge(src proto.Message)
- func (m *FeatureReference) XXX_Size() int
- func (m *FeatureReference) XXX_Unmarshal(b []byte) error
- type GetBatchFeaturesRequest
- func (*GetBatchFeaturesRequest) Descriptor() ([]byte, []int)
- func (m *GetBatchFeaturesRequest) GetDatasetSource() *DatasetSource
- func (m *GetBatchFeaturesRequest) GetFeatures() []*FeatureReference
- func (*GetBatchFeaturesRequest) ProtoMessage()
- func (m *GetBatchFeaturesRequest) Reset()
- func (m *GetBatchFeaturesRequest) String() string
- func (m *GetBatchFeaturesRequest) XXX_DiscardUnknown()
- func (m *GetBatchFeaturesRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *GetBatchFeaturesRequest) XXX_Merge(src proto.Message)
- func (m *GetBatchFeaturesRequest) XXX_Size() int
- func (m *GetBatchFeaturesRequest) XXX_Unmarshal(b []byte) error
- type GetBatchFeaturesResponse
- func (*GetBatchFeaturesResponse) Descriptor() ([]byte, []int)
- func (m *GetBatchFeaturesResponse) GetJob() *Job
- func (*GetBatchFeaturesResponse) ProtoMessage()
- func (m *GetBatchFeaturesResponse) Reset()
- func (m *GetBatchFeaturesResponse) String() string
- func (m *GetBatchFeaturesResponse) XXX_DiscardUnknown()
- func (m *GetBatchFeaturesResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *GetBatchFeaturesResponse) XXX_Merge(src proto.Message)
- func (m *GetBatchFeaturesResponse) XXX_Size() int
- func (m *GetBatchFeaturesResponse) XXX_Unmarshal(b []byte) error
- type GetFeastServingInfoRequest
- func (*GetFeastServingInfoRequest) Descriptor() ([]byte, []int)
- func (*GetFeastServingInfoRequest) ProtoMessage()
- func (m *GetFeastServingInfoRequest) Reset()
- func (m *GetFeastServingInfoRequest) String() string
- func (m *GetFeastServingInfoRequest) XXX_DiscardUnknown()
- func (m *GetFeastServingInfoRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *GetFeastServingInfoRequest) XXX_Merge(src proto.Message)
- func (m *GetFeastServingInfoRequest) XXX_Size() int
- func (m *GetFeastServingInfoRequest) XXX_Unmarshal(b []byte) error
- type GetFeastServingInfoResponse
- func (*GetFeastServingInfoResponse) Descriptor() ([]byte, []int)
- func (m *GetFeastServingInfoResponse) GetJobStagingLocation() string
- func (m *GetFeastServingInfoResponse) GetType() FeastServingType
- func (m *GetFeastServingInfoResponse) GetVersion() string
- func (*GetFeastServingInfoResponse) ProtoMessage()
- func (m *GetFeastServingInfoResponse) Reset()
- func (m *GetFeastServingInfoResponse) String() string
- func (m *GetFeastServingInfoResponse) XXX_DiscardUnknown()
- func (m *GetFeastServingInfoResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *GetFeastServingInfoResponse) XXX_Merge(src proto.Message)
- func (m *GetFeastServingInfoResponse) XXX_Size() int
- func (m *GetFeastServingInfoResponse) XXX_Unmarshal(b []byte) error
- type GetJobRequest
- func (*GetJobRequest) Descriptor() ([]byte, []int)
- func (m *GetJobRequest) GetJob() *Job
- func (*GetJobRequest) ProtoMessage()
- func (m *GetJobRequest) Reset()
- func (m *GetJobRequest) String() string
- func (m *GetJobRequest) XXX_DiscardUnknown()
- func (m *GetJobRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *GetJobRequest) XXX_Merge(src proto.Message)
- func (m *GetJobRequest) XXX_Size() int
- func (m *GetJobRequest) XXX_Unmarshal(b []byte) error
- type GetJobResponse
- func (*GetJobResponse) Descriptor() ([]byte, []int)
- func (m *GetJobResponse) GetJob() *Job
- func (*GetJobResponse) ProtoMessage()
- func (m *GetJobResponse) Reset()
- func (m *GetJobResponse) String() string
- func (m *GetJobResponse) XXX_DiscardUnknown()
- func (m *GetJobResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *GetJobResponse) XXX_Merge(src proto.Message)
- func (m *GetJobResponse) XXX_Size() int
- func (m *GetJobResponse) XXX_Unmarshal(b []byte) error
- type GetOnlineFeaturesRequest
- func (*GetOnlineFeaturesRequest) Descriptor() ([]byte, []int)
- func (m *GetOnlineFeaturesRequest) GetEntityRows() []*GetOnlineFeaturesRequest_EntityRow
- func (m *GetOnlineFeaturesRequest) GetFeatures() []*FeatureReference
- func (m *GetOnlineFeaturesRequest) GetOmitEntitiesInResponse() bool
- func (*GetOnlineFeaturesRequest) ProtoMessage()
- func (m *GetOnlineFeaturesRequest) Reset()
- func (m *GetOnlineFeaturesRequest) String() string
- func (m *GetOnlineFeaturesRequest) XXX_DiscardUnknown()
- func (m *GetOnlineFeaturesRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *GetOnlineFeaturesRequest) XXX_Merge(src proto.Message)
- func (m *GetOnlineFeaturesRequest) XXX_Size() int
- func (m *GetOnlineFeaturesRequest) XXX_Unmarshal(b []byte) error
- type GetOnlineFeaturesRequest_EntityRow
- func (*GetOnlineFeaturesRequest_EntityRow) Descriptor() ([]byte, []int)
- func (m *GetOnlineFeaturesRequest_EntityRow) GetEntityTimestamp() *timestamp.Timestamp
- func (m *GetOnlineFeaturesRequest_EntityRow) GetFields() map[string]*types.Value
- func (*GetOnlineFeaturesRequest_EntityRow) ProtoMessage()
- func (m *GetOnlineFeaturesRequest_EntityRow) Reset()
- func (m *GetOnlineFeaturesRequest_EntityRow) String() string
- func (m *GetOnlineFeaturesRequest_EntityRow) XXX_DiscardUnknown()
- func (m *GetOnlineFeaturesRequest_EntityRow) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *GetOnlineFeaturesRequest_EntityRow) XXX_Merge(src proto.Message)
- func (m *GetOnlineFeaturesRequest_EntityRow) XXX_Size() int
- func (m *GetOnlineFeaturesRequest_EntityRow) XXX_Unmarshal(b []byte) error
- type GetOnlineFeaturesResponse
- func (*GetOnlineFeaturesResponse) Descriptor() ([]byte, []int)
- func (m *GetOnlineFeaturesResponse) GetFieldValues() []*GetOnlineFeaturesResponse_FieldValues
- func (*GetOnlineFeaturesResponse) ProtoMessage()
- func (m *GetOnlineFeaturesResponse) Reset()
- func (m *GetOnlineFeaturesResponse) String() string
- func (m *GetOnlineFeaturesResponse) XXX_DiscardUnknown()
- func (m *GetOnlineFeaturesResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *GetOnlineFeaturesResponse) XXX_Merge(src proto.Message)
- func (m *GetOnlineFeaturesResponse) XXX_Size() int
- func (m *GetOnlineFeaturesResponse) XXX_Unmarshal(b []byte) error
- type GetOnlineFeaturesResponse_FieldValues
- func (*GetOnlineFeaturesResponse_FieldValues) Descriptor() ([]byte, []int)
- func (m *GetOnlineFeaturesResponse_FieldValues) GetFields() map[string]*types.Value
- func (*GetOnlineFeaturesResponse_FieldValues) ProtoMessage()
- func (m *GetOnlineFeaturesResponse_FieldValues) Reset()
- func (m *GetOnlineFeaturesResponse_FieldValues) String() string
- func (m *GetOnlineFeaturesResponse_FieldValues) XXX_DiscardUnknown()
- func (m *GetOnlineFeaturesResponse_FieldValues) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *GetOnlineFeaturesResponse_FieldValues) XXX_Merge(src proto.Message)
- func (m *GetOnlineFeaturesResponse_FieldValues) XXX_Size() int
- func (m *GetOnlineFeaturesResponse_FieldValues) XXX_Unmarshal(b []byte) error
- type Job
- func (*Job) Descriptor() ([]byte, []int)
- func (m *Job) GetDataFormat() DataFormat
- func (m *Job) GetError() string
- func (m *Job) GetFileUris() []string
- func (m *Job) GetId() string
- func (m *Job) GetStatus() JobStatus
- func (m *Job) GetType() JobType
- func (*Job) ProtoMessage()
- func (m *Job) Reset()
- func (m *Job) String() string
- func (m *Job) XXX_DiscardUnknown()
- func (m *Job) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *Job) XXX_Merge(src proto.Message)
- func (m *Job) XXX_Size() int
- func (m *Job) XXX_Unmarshal(b []byte) error
- type JobStatus
- type JobType
- type ServingServiceClient
- type ServingServiceServer
- type UnimplementedServingServiceServer
- func (*UnimplementedServingServiceServer) GetBatchFeatures(ctx context.Context, req *GetBatchFeaturesRequest) (*GetBatchFeaturesResponse, error)
- func (*UnimplementedServingServiceServer) GetFeastServingInfo(ctx context.Context, req *GetFeastServingInfoRequest) (*GetFeastServingInfoResponse, error)
- func (*UnimplementedServingServiceServer) GetJob(ctx context.Context, req *GetJobRequest) (*GetJobResponse, error)
- func (*UnimplementedServingServiceServer) GetOnlineFeatures(ctx context.Context, req *GetOnlineFeaturesRequest) (*GetOnlineFeaturesResponse, error)
Constants ¶
This section is empty.
Variables ¶
var DataFormat_name = map[int32]string{
0: "DATA_FORMAT_INVALID",
1: "DATA_FORMAT_AVRO",
}
var DataFormat_value = map[string]int32{
"DATA_FORMAT_INVALID": 0,
"DATA_FORMAT_AVRO": 1,
}
var FeastServingType_name = map[int32]string{
0: "FEAST_SERVING_TYPE_INVALID",
1: "FEAST_SERVING_TYPE_ONLINE",
2: "FEAST_SERVING_TYPE_BATCH",
}
var FeastServingType_value = map[string]int32{
"FEAST_SERVING_TYPE_INVALID": 0,
"FEAST_SERVING_TYPE_ONLINE": 1,
"FEAST_SERVING_TYPE_BATCH": 2,
}
var JobStatus_name = map[int32]string{
0: "JOB_STATUS_INVALID",
1: "JOB_STATUS_PENDING",
2: "JOB_STATUS_RUNNING",
3: "JOB_STATUS_DONE",
}
var JobStatus_value = map[string]int32{
"JOB_STATUS_INVALID": 0,
"JOB_STATUS_PENDING": 1,
"JOB_STATUS_RUNNING": 2,
"JOB_STATUS_DONE": 3,
}
var JobType_name = map[int32]string{
0: "JOB_TYPE_INVALID",
1: "JOB_TYPE_DOWNLOAD",
}
var JobType_value = map[string]int32{
"JOB_TYPE_INVALID": 0,
"JOB_TYPE_DOWNLOAD": 1,
}
Functions ¶
func RegisterServingServiceServer ¶
func RegisterServingServiceServer(s *grpc.Server, srv ServingServiceServer)
Types ¶
type DataFormat ¶
type DataFormat int32
const ( DataFormat_DATA_FORMAT_INVALID DataFormat = 0 DataFormat_DATA_FORMAT_AVRO DataFormat = 1 )
func (DataFormat) EnumDescriptor ¶
func (DataFormat) EnumDescriptor() ([]byte, []int)
func (DataFormat) String ¶
func (x DataFormat) String() string
type DatasetSource ¶
type DatasetSource struct {
// Types that are valid to be assigned to DatasetSource:
// *DatasetSource_FileSource_
DatasetSource isDatasetSource_DatasetSource `protobuf_oneof:"dataset_source"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*DatasetSource) Descriptor ¶
func (*DatasetSource) Descriptor() ([]byte, []int)
func (*DatasetSource) GetDatasetSource ¶
func (m *DatasetSource) GetDatasetSource() isDatasetSource_DatasetSource
func (*DatasetSource) GetFileSource ¶
func (m *DatasetSource) GetFileSource() *DatasetSource_FileSource
func (*DatasetSource) ProtoMessage ¶
func (*DatasetSource) ProtoMessage()
func (*DatasetSource) Reset ¶
func (m *DatasetSource) Reset()
func (*DatasetSource) String ¶
func (m *DatasetSource) String() string
func (*DatasetSource) XXX_DiscardUnknown ¶
func (m *DatasetSource) XXX_DiscardUnknown()
func (*DatasetSource) XXX_Marshal ¶
func (m *DatasetSource) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*DatasetSource) XXX_Merge ¶
func (m *DatasetSource) XXX_Merge(src proto.Message)
func (*DatasetSource) XXX_OneofWrappers ¶
func (*DatasetSource) XXX_OneofWrappers() []interface{}
XXX_OneofWrappers is for the internal use of the proto package.
func (*DatasetSource) XXX_Size ¶
func (m *DatasetSource) XXX_Size() int
func (*DatasetSource) XXX_Unmarshal ¶
func (m *DatasetSource) XXX_Unmarshal(b []byte) error
type DatasetSource_FileSource ¶
type DatasetSource_FileSource struct {
// URIs to retrieve the dataset from, e.g. gs://bucket/directory/object.csv. Wildcards are
// supported. This data must be compatible to be uploaded to the serving store, and also be
// accessible by this serving instance.
FileUris []string `protobuf:"bytes,1,rep,name=file_uris,json=fileUris,proto3" json:"file_uris,omitempty"`
// Format of the data. Currently only avro is supported.
DataFormat DataFormat `protobuf:"varint,2,opt,name=data_format,json=dataFormat,proto3,enum=feast.serving.DataFormat" json:"data_format,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*DatasetSource_FileSource) Descriptor ¶
func (*DatasetSource_FileSource) Descriptor() ([]byte, []int)
func (*DatasetSource_FileSource) GetDataFormat ¶
func (m *DatasetSource_FileSource) GetDataFormat() DataFormat
func (*DatasetSource_FileSource) GetFileUris ¶
func (m *DatasetSource_FileSource) GetFileUris() []string
func (*DatasetSource_FileSource) ProtoMessage ¶
func (*DatasetSource_FileSource) ProtoMessage()
func (*DatasetSource_FileSource) Reset ¶
func (m *DatasetSource_FileSource) Reset()
func (*DatasetSource_FileSource) String ¶
func (m *DatasetSource_FileSource) String() string
func (*DatasetSource_FileSource) XXX_DiscardUnknown ¶
func (m *DatasetSource_FileSource) XXX_DiscardUnknown()
func (*DatasetSource_FileSource) XXX_Marshal ¶
func (m *DatasetSource_FileSource) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*DatasetSource_FileSource) XXX_Merge ¶
func (m *DatasetSource_FileSource) XXX_Merge(src proto.Message)
func (*DatasetSource_FileSource) XXX_Size ¶
func (m *DatasetSource_FileSource) XXX_Size() int
func (*DatasetSource_FileSource) XXX_Unmarshal ¶
func (m *DatasetSource_FileSource) XXX_Unmarshal(b []byte) error
type DatasetSource_FileSource_ ¶
type DatasetSource_FileSource_ struct {
FileSource *DatasetSource_FileSource `protobuf:"bytes,1,opt,name=file_source,json=fileSource,proto3,oneof"`
}
type FeastServingType ¶
type FeastServingType int32
const ( FeastServingType_FEAST_SERVING_TYPE_INVALID FeastServingType = 0 // Online serving receives entity data directly and synchronously and will // respond immediately. FeastServingType_FEAST_SERVING_TYPE_ONLINE FeastServingType = 1 // Batch serving receives entity data asynchronously and orchestrates the // retrieval through a staging location. FeastServingType_FEAST_SERVING_TYPE_BATCH FeastServingType = 2 )
func (FeastServingType) EnumDescriptor ¶
func (FeastServingType) EnumDescriptor() ([]byte, []int)
func (FeastServingType) String ¶
func (x FeastServingType) String() string
type FeatureReference ¶
type FeatureReference struct {
// Project name
Project string `protobuf:"bytes,1,opt,name=project,proto3" json:"project,omitempty"`
// Feature name
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
// Feature version
Version int32 `protobuf:"varint,3,opt,name=version,proto3" json:"version,omitempty"`
// The features will be retrieved if:
// entity_timestamp - max_age <= event_timestamp <= entity_timestamp
//
// If unspecified the default max_age specified in FeatureSetSpec will
// be used.
MaxAge *duration.Duration `protobuf:"bytes,4,opt,name=max_age,json=maxAge,proto3" json:"max_age,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*FeatureReference) Descriptor ¶
func (*FeatureReference) Descriptor() ([]byte, []int)
func (*FeatureReference) GetMaxAge ¶
func (m *FeatureReference) GetMaxAge() *duration.Duration
func (*FeatureReference) GetName ¶
func (m *FeatureReference) GetName() string
func (*FeatureReference) GetProject ¶
func (m *FeatureReference) GetProject() string
func (*FeatureReference) GetVersion ¶
func (m *FeatureReference) GetVersion() int32
func (*FeatureReference) ProtoMessage ¶
func (*FeatureReference) ProtoMessage()
func (*FeatureReference) Reset ¶
func (m *FeatureReference) Reset()
func (*FeatureReference) String ¶
func (m *FeatureReference) String() string
func (*FeatureReference) XXX_DiscardUnknown ¶
func (m *FeatureReference) XXX_DiscardUnknown()
func (*FeatureReference) XXX_Marshal ¶
func (m *FeatureReference) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*FeatureReference) XXX_Merge ¶
func (m *FeatureReference) XXX_Merge(src proto.Message)
func (*FeatureReference) XXX_Size ¶
func (m *FeatureReference) XXX_Size() int
func (*FeatureReference) XXX_Unmarshal ¶
func (m *FeatureReference) XXX_Unmarshal(b []byte) error
type GetBatchFeaturesRequest ¶
type GetBatchFeaturesRequest struct {
// List of features that are being retrieved
Features []*FeatureReference `protobuf:"bytes,3,rep,name=features,proto3" json:"features,omitempty"`
// Source of the entity dataset containing the timestamps and entity keys to retrieve
// features for.
DatasetSource *DatasetSource `protobuf:"bytes,2,opt,name=dataset_source,json=datasetSource,proto3" json:"dataset_source,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*GetBatchFeaturesRequest) Descriptor ¶
func (*GetBatchFeaturesRequest) Descriptor() ([]byte, []int)
func (*GetBatchFeaturesRequest) GetDatasetSource ¶
func (m *GetBatchFeaturesRequest) GetDatasetSource() *DatasetSource
func (*GetBatchFeaturesRequest) GetFeatures ¶
func (m *GetBatchFeaturesRequest) GetFeatures() []*FeatureReference
func (*GetBatchFeaturesRequest) ProtoMessage ¶
func (*GetBatchFeaturesRequest) ProtoMessage()
func (*GetBatchFeaturesRequest) Reset ¶
func (m *GetBatchFeaturesRequest) Reset()
func (*GetBatchFeaturesRequest) String ¶
func (m *GetBatchFeaturesRequest) String() string
func (*GetBatchFeaturesRequest) XXX_DiscardUnknown ¶
func (m *GetBatchFeaturesRequest) XXX_DiscardUnknown()
func (*GetBatchFeaturesRequest) XXX_Marshal ¶
func (m *GetBatchFeaturesRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*GetBatchFeaturesRequest) XXX_Merge ¶
func (m *GetBatchFeaturesRequest) XXX_Merge(src proto.Message)
func (*GetBatchFeaturesRequest) XXX_Size ¶
func (m *GetBatchFeaturesRequest) XXX_Size() int
func (*GetBatchFeaturesRequest) XXX_Unmarshal ¶
func (m *GetBatchFeaturesRequest) XXX_Unmarshal(b []byte) error
type GetBatchFeaturesResponse ¶
type GetBatchFeaturesResponse struct {
Job *Job `protobuf:"bytes,1,opt,name=job,proto3" json:"job,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*GetBatchFeaturesResponse) Descriptor ¶
func (*GetBatchFeaturesResponse) Descriptor() ([]byte, []int)
func (*GetBatchFeaturesResponse) GetJob ¶
func (m *GetBatchFeaturesResponse) GetJob() *Job
func (*GetBatchFeaturesResponse) ProtoMessage ¶
func (*GetBatchFeaturesResponse) ProtoMessage()
func (*GetBatchFeaturesResponse) Reset ¶
func (m *GetBatchFeaturesResponse) Reset()
func (*GetBatchFeaturesResponse) String ¶
func (m *GetBatchFeaturesResponse) String() string
func (*GetBatchFeaturesResponse) XXX_DiscardUnknown ¶
func (m *GetBatchFeaturesResponse) XXX_DiscardUnknown()
func (*GetBatchFeaturesResponse) XXX_Marshal ¶
func (m *GetBatchFeaturesResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*GetBatchFeaturesResponse) XXX_Merge ¶
func (m *GetBatchFeaturesResponse) XXX_Merge(src proto.Message)
func (*GetBatchFeaturesResponse) XXX_Size ¶
func (m *GetBatchFeaturesResponse) XXX_Size() int
func (*GetBatchFeaturesResponse) XXX_Unmarshal ¶
func (m *GetBatchFeaturesResponse) XXX_Unmarshal(b []byte) error
type GetFeastServingInfoRequest ¶
type GetFeastServingInfoRequest struct {
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*GetFeastServingInfoRequest) Descriptor ¶
func (*GetFeastServingInfoRequest) Descriptor() ([]byte, []int)
func (*GetFeastServingInfoRequest) ProtoMessage ¶
func (*GetFeastServingInfoRequest) ProtoMessage()
func (*GetFeastServingInfoRequest) Reset ¶
func (m *GetFeastServingInfoRequest) Reset()
func (*GetFeastServingInfoRequest) String ¶
func (m *GetFeastServingInfoRequest) String() string
func (*GetFeastServingInfoRequest) XXX_DiscardUnknown ¶
func (m *GetFeastServingInfoRequest) XXX_DiscardUnknown()
func (*GetFeastServingInfoRequest) XXX_Marshal ¶
func (m *GetFeastServingInfoRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*GetFeastServingInfoRequest) XXX_Merge ¶
func (m *GetFeastServingInfoRequest) XXX_Merge(src proto.Message)
func (*GetFeastServingInfoRequest) XXX_Size ¶
func (m *GetFeastServingInfoRequest) XXX_Size() int
func (*GetFeastServingInfoRequest) XXX_Unmarshal ¶
func (m *GetFeastServingInfoRequest) XXX_Unmarshal(b []byte) error
type GetFeastServingInfoResponse ¶
type GetFeastServingInfoResponse struct {
// Feast version of this serving deployment.
Version string `protobuf:"bytes,1,opt,name=version,proto3" json:"version,omitempty"`
// Type of serving deployment, either ONLINE or BATCH. Different store types support different
// feature retrieval methods.
Type FeastServingType `protobuf:"varint,2,opt,name=type,proto3,enum=feast.serving.FeastServingType" json:"type,omitempty"`
// Note: Batch specific options start from 10.
// Staging location for this serving store, if any.
JobStagingLocation string `protobuf:"bytes,10,opt,name=job_staging_location,json=jobStagingLocation,proto3" json:"job_staging_location,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*GetFeastServingInfoResponse) Descriptor ¶
func (*GetFeastServingInfoResponse) Descriptor() ([]byte, []int)
func (*GetFeastServingInfoResponse) GetJobStagingLocation ¶
func (m *GetFeastServingInfoResponse) GetJobStagingLocation() string
func (*GetFeastServingInfoResponse) GetType ¶
func (m *GetFeastServingInfoResponse) GetType() FeastServingType
func (*GetFeastServingInfoResponse) GetVersion ¶
func (m *GetFeastServingInfoResponse) GetVersion() string
func (*GetFeastServingInfoResponse) ProtoMessage ¶
func (*GetFeastServingInfoResponse) ProtoMessage()
func (*GetFeastServingInfoResponse) Reset ¶
func (m *GetFeastServingInfoResponse) Reset()
func (*GetFeastServingInfoResponse) String ¶
func (m *GetFeastServingInfoResponse) String() string
func (*GetFeastServingInfoResponse) XXX_DiscardUnknown ¶
func (m *GetFeastServingInfoResponse) XXX_DiscardUnknown()
func (*GetFeastServingInfoResponse) XXX_Marshal ¶
func (m *GetFeastServingInfoResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*GetFeastServingInfoResponse) XXX_Merge ¶
func (m *GetFeastServingInfoResponse) XXX_Merge(src proto.Message)
func (*GetFeastServingInfoResponse) XXX_Size ¶
func (m *GetFeastServingInfoResponse) XXX_Size() int
func (*GetFeastServingInfoResponse) XXX_Unmarshal ¶
func (m *GetFeastServingInfoResponse) XXX_Unmarshal(b []byte) error
type GetJobRequest ¶
type GetJobRequest struct {
Job *Job `protobuf:"bytes,1,opt,name=job,proto3" json:"job,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*GetJobRequest) Descriptor ¶
func (*GetJobRequest) Descriptor() ([]byte, []int)
func (*GetJobRequest) GetJob ¶
func (m *GetJobRequest) GetJob() *Job
func (*GetJobRequest) ProtoMessage ¶
func (*GetJobRequest) ProtoMessage()
func (*GetJobRequest) Reset ¶
func (m *GetJobRequest) Reset()
func (*GetJobRequest) String ¶
func (m *GetJobRequest) String() string
func (*GetJobRequest) XXX_DiscardUnknown ¶
func (m *GetJobRequest) XXX_DiscardUnknown()
func (*GetJobRequest) XXX_Marshal ¶
func (m *GetJobRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*GetJobRequest) XXX_Merge ¶
func (m *GetJobRequest) XXX_Merge(src proto.Message)
func (*GetJobRequest) XXX_Size ¶
func (m *GetJobRequest) XXX_Size() int
func (*GetJobRequest) XXX_Unmarshal ¶
func (m *GetJobRequest) XXX_Unmarshal(b []byte) error
type GetJobResponse ¶
type GetJobResponse struct {
Job *Job `protobuf:"bytes,1,opt,name=job,proto3" json:"job,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*GetJobResponse) Descriptor ¶
func (*GetJobResponse) Descriptor() ([]byte, []int)
func (*GetJobResponse) GetJob ¶
func (m *GetJobResponse) GetJob() *Job
func (*GetJobResponse) ProtoMessage ¶
func (*GetJobResponse) ProtoMessage()
func (*GetJobResponse) Reset ¶
func (m *GetJobResponse) Reset()
func (*GetJobResponse) String ¶
func (m *GetJobResponse) String() string
func (*GetJobResponse) XXX_DiscardUnknown ¶
func (m *GetJobResponse) XXX_DiscardUnknown()
func (*GetJobResponse) XXX_Marshal ¶
func (m *GetJobResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*GetJobResponse) XXX_Merge ¶
func (m *GetJobResponse) XXX_Merge(src proto.Message)
func (*GetJobResponse) XXX_Size ¶
func (m *GetJobResponse) XXX_Size() int
func (*GetJobResponse) XXX_Unmarshal ¶
func (m *GetJobResponse) XXX_Unmarshal(b []byte) error
type GetOnlineFeaturesRequest ¶
type GetOnlineFeaturesRequest struct {
// List of features that are being retrieved
Features []*FeatureReference `protobuf:"bytes,4,rep,name=features,proto3" json:"features,omitempty"`
// List of entity rows, containing entity id and timestamp data.
// Used during retrieval of feature rows and for joining feature
// rows into a final dataset
EntityRows []*GetOnlineFeaturesRequest_EntityRow `protobuf:"bytes,2,rep,name=entity_rows,json=entityRows,proto3" json:"entity_rows,omitempty"`
// Option to omit entities from the response. If true, only feature
// values will be returned.
OmitEntitiesInResponse bool `` /* 132-byte string literal not displayed */
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*GetOnlineFeaturesRequest) Descriptor ¶
func (*GetOnlineFeaturesRequest) Descriptor() ([]byte, []int)
func (*GetOnlineFeaturesRequest) GetEntityRows ¶
func (m *GetOnlineFeaturesRequest) GetEntityRows() []*GetOnlineFeaturesRequest_EntityRow
func (*GetOnlineFeaturesRequest) GetFeatures ¶
func (m *GetOnlineFeaturesRequest) GetFeatures() []*FeatureReference
func (*GetOnlineFeaturesRequest) GetOmitEntitiesInResponse ¶
func (m *GetOnlineFeaturesRequest) GetOmitEntitiesInResponse() bool
func (*GetOnlineFeaturesRequest) ProtoMessage ¶
func (*GetOnlineFeaturesRequest) ProtoMessage()
func (*GetOnlineFeaturesRequest) Reset ¶
func (m *GetOnlineFeaturesRequest) Reset()
func (*GetOnlineFeaturesRequest) String ¶
func (m *GetOnlineFeaturesRequest) String() string
func (*GetOnlineFeaturesRequest) XXX_DiscardUnknown ¶
func (m *GetOnlineFeaturesRequest) XXX_DiscardUnknown()
func (*GetOnlineFeaturesRequest) XXX_Marshal ¶
func (m *GetOnlineFeaturesRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*GetOnlineFeaturesRequest) XXX_Merge ¶
func (m *GetOnlineFeaturesRequest) XXX_Merge(src proto.Message)
func (*GetOnlineFeaturesRequest) XXX_Size ¶
func (m *GetOnlineFeaturesRequest) XXX_Size() int
func (*GetOnlineFeaturesRequest) XXX_Unmarshal ¶
func (m *GetOnlineFeaturesRequest) XXX_Unmarshal(b []byte) error
type GetOnlineFeaturesRequest_EntityRow ¶
type GetOnlineFeaturesRequest_EntityRow struct {
// Request timestamp of this row. This value will be used, together with maxAge,
// to determine feature staleness.
EntityTimestamp *timestamp.Timestamp `protobuf:"bytes,1,opt,name=entity_timestamp,json=entityTimestamp,proto3" json:"entity_timestamp,omitempty"`
// Map containing mapping of entity name to entity value.
Fields map[string]*types.Value `` /* 153-byte string literal not displayed */
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*GetOnlineFeaturesRequest_EntityRow) Descriptor ¶
func (*GetOnlineFeaturesRequest_EntityRow) Descriptor() ([]byte, []int)
func (*GetOnlineFeaturesRequest_EntityRow) GetEntityTimestamp ¶
func (m *GetOnlineFeaturesRequest_EntityRow) GetEntityTimestamp() *timestamp.Timestamp
func (*GetOnlineFeaturesRequest_EntityRow) GetFields ¶
func (m *GetOnlineFeaturesRequest_EntityRow) GetFields() map[string]*types.Value
func (*GetOnlineFeaturesRequest_EntityRow) ProtoMessage ¶
func (*GetOnlineFeaturesRequest_EntityRow) ProtoMessage()
func (*GetOnlineFeaturesRequest_EntityRow) Reset ¶
func (m *GetOnlineFeaturesRequest_EntityRow) Reset()
func (*GetOnlineFeaturesRequest_EntityRow) String ¶
func (m *GetOnlineFeaturesRequest_EntityRow) String() string
func (*GetOnlineFeaturesRequest_EntityRow) XXX_DiscardUnknown ¶
func (m *GetOnlineFeaturesRequest_EntityRow) XXX_DiscardUnknown()
func (*GetOnlineFeaturesRequest_EntityRow) XXX_Marshal ¶
func (m *GetOnlineFeaturesRequest_EntityRow) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*GetOnlineFeaturesRequest_EntityRow) XXX_Merge ¶
func (m *GetOnlineFeaturesRequest_EntityRow) XXX_Merge(src proto.Message)
func (*GetOnlineFeaturesRequest_EntityRow) XXX_Size ¶
func (m *GetOnlineFeaturesRequest_EntityRow) XXX_Size() int
func (*GetOnlineFeaturesRequest_EntityRow) XXX_Unmarshal ¶
func (m *GetOnlineFeaturesRequest_EntityRow) XXX_Unmarshal(b []byte) error
type GetOnlineFeaturesResponse ¶
type GetOnlineFeaturesResponse struct {
// Feature values retrieved from feast.
FieldValues []*GetOnlineFeaturesResponse_FieldValues `protobuf:"bytes,1,rep,name=field_values,json=fieldValues,proto3" json:"field_values,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*GetOnlineFeaturesResponse) Descriptor ¶
func (*GetOnlineFeaturesResponse) Descriptor() ([]byte, []int)
func (*GetOnlineFeaturesResponse) GetFieldValues ¶
func (m *GetOnlineFeaturesResponse) GetFieldValues() []*GetOnlineFeaturesResponse_FieldValues
func (*GetOnlineFeaturesResponse) ProtoMessage ¶
func (*GetOnlineFeaturesResponse) ProtoMessage()
func (*GetOnlineFeaturesResponse) Reset ¶
func (m *GetOnlineFeaturesResponse) Reset()
func (*GetOnlineFeaturesResponse) String ¶
func (m *GetOnlineFeaturesResponse) String() string
func (*GetOnlineFeaturesResponse) XXX_DiscardUnknown ¶
func (m *GetOnlineFeaturesResponse) XXX_DiscardUnknown()
func (*GetOnlineFeaturesResponse) XXX_Marshal ¶
func (m *GetOnlineFeaturesResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*GetOnlineFeaturesResponse) XXX_Merge ¶
func (m *GetOnlineFeaturesResponse) XXX_Merge(src proto.Message)
func (*GetOnlineFeaturesResponse) XXX_Size ¶
func (m *GetOnlineFeaturesResponse) XXX_Size() int
func (*GetOnlineFeaturesResponse) XXX_Unmarshal ¶
func (m *GetOnlineFeaturesResponse) XXX_Unmarshal(b []byte) error
type GetOnlineFeaturesResponse_FieldValues ¶
type GetOnlineFeaturesResponse_FieldValues struct {
// Map of feature or entity name to feature/entity values.
// Timestamps are not returned in this response.
Fields map[string]*types.Value `` /* 153-byte string literal not displayed */
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*GetOnlineFeaturesResponse_FieldValues) Descriptor ¶
func (*GetOnlineFeaturesResponse_FieldValues) Descriptor() ([]byte, []int)
func (*GetOnlineFeaturesResponse_FieldValues) GetFields ¶
func (m *GetOnlineFeaturesResponse_FieldValues) GetFields() map[string]*types.Value
func (*GetOnlineFeaturesResponse_FieldValues) ProtoMessage ¶
func (*GetOnlineFeaturesResponse_FieldValues) ProtoMessage()
func (*GetOnlineFeaturesResponse_FieldValues) Reset ¶
func (m *GetOnlineFeaturesResponse_FieldValues) Reset()
func (*GetOnlineFeaturesResponse_FieldValues) String ¶
func (m *GetOnlineFeaturesResponse_FieldValues) String() string
func (*GetOnlineFeaturesResponse_FieldValues) XXX_DiscardUnknown ¶
func (m *GetOnlineFeaturesResponse_FieldValues) XXX_DiscardUnknown()
func (*GetOnlineFeaturesResponse_FieldValues) XXX_Marshal ¶
func (m *GetOnlineFeaturesResponse_FieldValues) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*GetOnlineFeaturesResponse_FieldValues) XXX_Merge ¶
func (m *GetOnlineFeaturesResponse_FieldValues) XXX_Merge(src proto.Message)
func (*GetOnlineFeaturesResponse_FieldValues) XXX_Size ¶
func (m *GetOnlineFeaturesResponse_FieldValues) XXX_Size() int
func (*GetOnlineFeaturesResponse_FieldValues) XXX_Unmarshal ¶
func (m *GetOnlineFeaturesResponse_FieldValues) XXX_Unmarshal(b []byte) error
type Job ¶
type Job struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
// Output only. The type of the job.
Type JobType `protobuf:"varint,2,opt,name=type,proto3,enum=feast.serving.JobType" json:"type,omitempty"`
// Output only. Current state of the job.
Status JobStatus `protobuf:"varint,3,opt,name=status,proto3,enum=feast.serving.JobStatus" json:"status,omitempty"`
// Output only. If not empty, the job has failed with this error message.
Error string `protobuf:"bytes,4,opt,name=error,proto3" json:"error,omitempty"`
// Output only. The list of URIs for the files to be downloaded or
// uploaded (depends on the job type) for this particular job.
FileUris []string `protobuf:"bytes,5,rep,name=file_uris,json=fileUris,proto3" json:"file_uris,omitempty"`
// Output only. The data format for all the files.
// For CSV format, the files contain both feature values and a column header.
DataFormat DataFormat `protobuf:"varint,6,opt,name=data_format,json=dataFormat,proto3,enum=feast.serving.DataFormat" json:"data_format,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*Job) Descriptor ¶
func (*Job) GetDataFormat ¶
func (m *Job) GetDataFormat() DataFormat
func (*Job) GetFileUris ¶
func (*Job) ProtoMessage ¶
func (*Job) ProtoMessage()
func (*Job) XXX_DiscardUnknown ¶
func (m *Job) XXX_DiscardUnknown()
func (*Job) XXX_Unmarshal ¶
type ServingServiceClient ¶
type ServingServiceClient interface {
// Get information about this Feast serving.
GetFeastServingInfo(ctx context.Context, in *GetFeastServingInfoRequest, opts ...grpc.CallOption) (*GetFeastServingInfoResponse, error)
// Get online features synchronously.
GetOnlineFeatures(ctx context.Context, in *GetOnlineFeaturesRequest, opts ...grpc.CallOption) (*GetOnlineFeaturesResponse, error)
// Get batch features asynchronously.
//
// The client should check the status of the returned job periodically by
// calling ReloadJob to determine if the job has completed successfully
// or with an error. If the job completes successfully i.e.
// status = JOB_STATUS_DONE with no error, then the client can check
// the file_uris for the location to download feature values data.
// The client is assumed to have access to these file URIs.
GetBatchFeatures(ctx context.Context, in *GetBatchFeaturesRequest, opts ...grpc.CallOption) (*GetBatchFeaturesResponse, error)
// Get the latest job status for batch feature retrieval.
GetJob(ctx context.Context, in *GetJobRequest, opts ...grpc.CallOption) (*GetJobResponse, error)
}
ServingServiceClient is the client API for ServingService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
func NewServingServiceClient ¶
func NewServingServiceClient(cc *grpc.ClientConn) ServingServiceClient
type ServingServiceServer ¶
type ServingServiceServer interface {
// Get information about this Feast serving.
GetFeastServingInfo(context.Context, *GetFeastServingInfoRequest) (*GetFeastServingInfoResponse, error)
// Get online features synchronously.
GetOnlineFeatures(context.Context, *GetOnlineFeaturesRequest) (*GetOnlineFeaturesResponse, error)
// Get batch features asynchronously.
//
// The client should check the status of the returned job periodically by
// calling ReloadJob to determine if the job has completed successfully
// or with an error. If the job completes successfully i.e.
// status = JOB_STATUS_DONE with no error, then the client can check
// the file_uris for the location to download feature values data.
// The client is assumed to have access to these file URIs.
GetBatchFeatures(context.Context, *GetBatchFeaturesRequest) (*GetBatchFeaturesResponse, error)
// Get the latest job status for batch feature retrieval.
GetJob(context.Context, *GetJobRequest) (*GetJobResponse, error)
}
ServingServiceServer is the server API for ServingService service.
type UnimplementedServingServiceServer ¶
type UnimplementedServingServiceServer struct {
}
UnimplementedServingServiceServer can be embedded to have forward compatible implementations.
func (*UnimplementedServingServiceServer) GetBatchFeatures ¶
func (*UnimplementedServingServiceServer) GetBatchFeatures(ctx context.Context, req *GetBatchFeaturesRequest) (*GetBatchFeaturesResponse, error)
func (*UnimplementedServingServiceServer) GetFeastServingInfo ¶
func (*UnimplementedServingServiceServer) GetFeastServingInfo(ctx context.Context, req *GetFeastServingInfoRequest) (*GetFeastServingInfoResponse, error)
func (*UnimplementedServingServiceServer) GetJob ¶
func (*UnimplementedServingServiceServer) GetJob(ctx context.Context, req *GetJobRequest) (*GetJobResponse, error)
func (*UnimplementedServingServiceServer) GetOnlineFeatures ¶
func (*UnimplementedServingServiceServer) GetOnlineFeatures(ctx context.Context, req *GetOnlineFeaturesRequest) (*GetOnlineFeaturesResponse, error)
Click to show internal directories.
Click to hide internal directories.